# Skillful-Nowcasting
Implementation of DeepMind's Skillful Nowcasting GAN (https://arxiv.org/abs/2104.00954) in PyTorch Lightning.

## Installation

Clone the repository, then run
```shell
pip install -r requirements.txt
pip install -e .
````

Alternatively, you can also install a usually older version through ```pip install skillful-nowcasting```
